@@ -5,6 +5,7 @@ use strict;
 use warnings;
 use FindBin;
 use Test::More;
+use JSON::MaybeXS;
 
 BEGIN {
   eval { require WorePAN };
@@ -20,16 +21,13 @@ sub run {
 
   my ($name) = $file =~ /(\w+)\.t$/;
 
-  plan tests => scalar @tests;
-
   for my $test (@tests) {
     my $worepan = WorePAN->new(
-      root => "$FindBin::Bin/tmp",
+      root => "$FindBin::Bin/../../tmp",
       files => [$test->[0]],
       no_indices => 1,
       use_backpan => 1,
       no_network => 0,
-      cleanup => 1,
     );
     my $tarball = $worepan->file($test->[0]);
     my $analyzer = Module::CPANTS::Analyse->new({dist => $tarball});
@@ -38,7 +36,16 @@ sub run {
     my $metric = $analyzer->mck->get_indicators_hash->{$name};
     my $result = $metric->{code}->($analyzer->d);
     is $result => $test->[1], "$test->[0] $name: $result";
+
+    if (!$result) {
+      my $details = $metric->{details}->($analyzer->d) || '';
+      ok $details, ref $details ? encode_json($details) : $details;
+    }
+    if ($test->[2]) {
+      note explain $analyzer->d;
+    }
   }
+  done_testing;
 }
 
 1;
